@@ -39,15 +39,13 @@ class HttpTestRequest:
         self.method = None
         self.path = None
         self.body = None
-        self.headers = None
+        self.headers = dict()
         self.app.build()
 
     def request(self, method, route, headers=None, json=None, data=""):
         self.method = method
         self.path = route
-        self.headers = {
-            "Pywss-Http-Test": "0.0.1",
-        }
+        self.set_header("Pywss-Http-Test", "0.0.1")
         self.set_headers(headers or {})
         if json:
             self.set_headers({"Content-Type": "application/json"})
@@ -73,7 +71,7 @@ class HttpTestRequest:
 
     def build(self) -> HttpTestResponse:
         if self.body:
-            self.headers["Content-Length"] = len(self.body.encode())
+            self.headers.setdefault("Content-Length", len(self.body.encode()))
         header_list = []
         for k, v in self.headers.items():
             header_list.append(f"{k}: {v}")
@@ -84,7 +82,7 @@ class HttpTestRequest:
         with s, c:
             c.sendall(req_message.encode())
             c.sendall("GET / HTTP/1.1\r\nConnection: close\r\n\r\n".encode())
-            self.app._(s, None)
+            self.app.handler_request(s, None)
             resp = c.makefile("rb", -1)
             return HttpTestResponse(resp.readlines())
 
